@@ -1,7 +1,8 @@
-import logging, requests, os, cgi
+import logging, os, cgi, requests
 from pathlib import Path
 
-from typing import overload, cast
+from typing import IO, overload, cast
+from urllib import request
 from urllib.parse import urlencode
 
 from .client import Client
@@ -70,26 +71,26 @@ _VIEWER = User.add_fragment(
 
 
 class ApiClient(Client):
-    """ Adds simple queries to the client wrapper """
+    """Adds simple queries to the client wrapper"""
 
     def settings(self) -> ApiSettings:
-        """ API instance settings """
+        """API instance settings"""
         return cast(
             ApiSettings, self.query_to_class(ApiSettings, _SETTINGS, path="settings")
         )
 
     def viewer(self) -> User:
-        """ Current logged in user """
+        """Current logged in user"""
         return cast(User, self.query_to_class(User, _VIEWER, path="viewer"))
 
     @overload
     def project(self, id: str) -> Project:  # type: ignore
-        """ Retrieve a project by ID """
+        """Retrieve a project by ID"""
         pass
 
     @overload
     def project(self, login: str, slug: str) -> Project:  # type: ignore
-        """ Retrieve a project by login and slug """
+        """Retrieve a project by login and slug"""
         pass
 
     def project(self, loginOrId: str, slug: str = None) -> Project:
@@ -135,11 +136,26 @@ class ApiClient(Client):
 
         return name, result
 
+    def upload_to_default_filesource(self, project: Project, file: IO, **kwargs):
+        """Takes in a project and file, and uploads the file to DataTorch Storage"""
+        storageId = project.storage_link_default().id
+        pathToUploadTo = ""
+        endpoint = f"{self.api_url}/file/v1/upload/{storageId}?path={pathToUploadTo}&import=false&datasetId="
+        print(endpoint)
+        # r = requests.post(endpoint, files={"file": file}, user=self.viewer)
+        r = requests.post(
+            endpoint,
+            files={"file": file},
+            headers={self.token_header: self._api_token},
+            stream=True,
+        )
+        print(r.text)
+
     # def files(self, where: Where = None, limit: int = 400) -> List[File]:
     #     return []
 
     def validate_endpoint(self) -> bool:
-        """ Returns true if provided endpoint is correct. """
+        """Returns true if provided endpoint is correct."""
         try:
             version = self.settings().api_version
             logger.info("Endpoint API version: {}".format(version))
